==> haskell-servant-server-0.16.2-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-server
version: 0.16.2
id: servant-server-0.16.2-KeCGntGw3o9E0YXd5fpMFl
key: servant-server-0.16.2-KeCGntGw3o9E0YXd5fpMFl
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://docs.servant.dev/
synopsis: A family of combinators for defining webservices APIs and serving them
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: ee7341fc8793c48527e953b9fb1b0fe6
exposed: True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.Handler Servant.Server.Internal.RouteResult
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Utils.StaticFiles
import-dirs: /usr/lib/ghc-8.6.5/site-local/servant-server-0.16.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/servant-server-0.16.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/servant-server-0.16.2
hs-libraries: HSservant-server-0.16.2-KeCGntGw3o9E0YXd5fpMFl
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 containers-0.6.0.1
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt filepath-1.4.2.1
    http-api-data-0.4.1-Gc0bKxYUFbHHGV70hcgEWB
    http-media-0.8.0.0-L25zQqkU26CA7yE3vl2O05
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh mtl-2.2.2
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    servant-0.16.2-A9S9bnGMEnCGQ5FhsLyszH
    string-conversions-0.4.0.1-LtuUK6ZkUgfAmoIrlRp9AZ
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1
    transformers-0.5.6.2
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    wai-app-static-3.1.6.3-ADLwZLaFtaOLEBaRQtN57h
    word8-0.1.3-Hij9fyb7arJ9SXwAnMfmS0
haddock-interfaces: /usr/share/doc/haskell-servant-server/html/servant-server.haddock
haddock-html: /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-server-0.16.2-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-server
version: 0.16.2
id: servant-server-0.16.2-AaMziSD7d1WGJUMxBIToT
key: servant-server-0.16.2-AaMziSD7d1WGJUMxBIToT
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://docs.servant.dev/
synopsis: A family of combinators for defining webservices APIs and serving them
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: 8ca1affb301a59e6834f9ecda4c417f3
exposed: True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.Handler Servant.Server.Internal.RouteResult
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Utils.StaticFiles
import-dirs: /usr/lib/ghc-8.6.5/site-local/servant-server-0.16.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/servant-server-0.16.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/servant-server-0.16.2
hs-libraries: HSservant-server-0.16.2-AaMziSD7d1WGJUMxBIToT
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 containers-0.6.0.1
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt filepath-1.4.2.1
    http-api-data-0.4.1-Gc0bKxYUFbHHGV70hcgEWB
    http-media-0.8.0.0-L25zQqkU26CA7yE3vl2O05
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh mtl-2.2.2
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    servant-0.16.2-A9S9bnGMEnCGQ5FhsLyszH
    string-conversions-0.4.0.1-LtuUK6ZkUgfAmoIrlRp9AZ
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1
    transformers-0.5.6.2
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    wai-app-static-3.1.6.3-KFNzdDlztPn42HNxJw8Skw
    word8-0.1.3-Hij9fyb7arJ9SXwAnMfmS0
haddock-interfaces: /usr/share/doc/haskell-servant-server/html/servant-server.haddock
haddock-html: /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
